#include <Wire.h>
#include <S11059.h>

#define s11059          0x2A
#define s11059_CONFIG   0x00
S11059 colorSensor;

bool s11059_exist;

void setup(void) {
  Serial.begin(9600);
  Wire.begin(); 

  s11059_exist = s11059_init();

}
 
void loop(void) {

  int color[4];
  if(s11059_exist){
    getColor(color);

    Serial.print("r: ");
    Serial.print( color[0] );
    Serial.print(" g: ");
    Serial.print( color[1] );
    Serial.print(" b: ");
    Serial.print( color[2] );
    Serial.print(" i: ");
    Serial.print( color[3] );
    Serial.println();
  }
  else Serial.println("No Sensor(S11059)");
  
  delay(200);
}


bool s11059_init(){

  int res;
  Wire.beginTransmission(s11059);
  Wire.write(s11059_CONFIG);
  Wire.write(0x00);
  res = Wire.endTransmission();
  
  // 積分モードを固定時間モードに設定
  colorSensor.setMode(S11059_MODE_FIXED);

  // ゲイン選択
  //   S11059_GAIN_HIGH: Highゲイン
  //   S11059_GAIN_LOW: Lowゲイン
  colorSensor.setGain(S11059_GAIN_HIGH);

  // 1色あたりの積分時間設定(下記は指定可能な定数ごとの固定時間モードの場合の積分時間)
  //   S11059_TINT0: 87.5 us
  //   S11059_TINT1: 1.4 ms
  //   S11059_TINT2: 22.4 ms
  //   S11059_TINT3: 179.2 ms
  colorSensor.setTint(S11059_TINT1);

  // ADCリセット、スリープ解除
  if (!colorSensor.reset()) {
    Serial.println("reset failed");
  }

  // ADCリセット解除、バスリリース
  if (!colorSensor.start()) {
    Serial.println("start failed");
  }

  if(res>0) return false;
  else return true;
}

void getColor(int rgbi[4]){
  // 積分時間よりも長く待機
  // 固定時間モード時のS11059.delay()で実行される待機処理の時間は
  // S11059.setTint(tint)で設定した値に応じて異なります
  colorSensor.delay();

  // センサのデータ用レジスタ(赤、緑、青、赤外)をまとめてリード
  if (colorSensor.update()) {
    rgbi[0] = colorSensor.getRed();
    rgbi[1] = colorSensor.getGreen();
    rgbi[2] = colorSensor.getBlue();
    rgbi[3] = colorSensor.getIR();
    //Serial.print(colorSensor.getBlue());
    //Serial.print(",");
  } else {
    Serial.println("update failed");
  }
}


